# System Bridge Connector - Python

[![CI](https://github.com/timmo001/system-bridge-connector-py/actions/workflows/ci.yml/badge.svg)](https://github.com/timmo001/system-bridge-connector-py/actions/workflows/ci.yml)

Python package for connecting to [System Bridge](https://github.com/timmo001/system-bridge).
